# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
TopLoc module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_toploc.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TopLoc
else:
    import _TopLoc

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TopLoc.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _TopLoc.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TopLoc.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TopLoc.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _TopLoc.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _TopLoc.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _TopLoc.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _TopLoc.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _TopLoc.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _TopLoc.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TopLoc.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _TopLoc.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _TopLoc.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TopLoc.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TopLoc.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TopLoc.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _TopLoc.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TopLoc:
_TopLoc.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _TopLoc.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_TopLoc_Datum3D_Create() -> "opencascade::handle< TopLoc_Datum3D >":
    return _TopLoc.Handle_TopLoc_Datum3D_Create()

def Handle_TopLoc_Datum3D_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TopLoc_Datum3D >":
    return _TopLoc.Handle_TopLoc_Datum3D_DownCast(t)

def Handle_TopLoc_Datum3D_IsNull(t: "opencascade::handle< TopLoc_Datum3D > const &") -> "bool":
    return _TopLoc.Handle_TopLoc_Datum3D_IsNull(t)

def Handle_TopLoc_SListNodeOfItemLocation_Create() -> "opencascade::handle< TopLoc_SListNodeOfItemLocation >":
    return _TopLoc.Handle_TopLoc_SListNodeOfItemLocation_Create()

def Handle_TopLoc_SListNodeOfItemLocation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TopLoc_SListNodeOfItemLocation >":
    return _TopLoc.Handle_TopLoc_SListNodeOfItemLocation_DownCast(t)

def Handle_TopLoc_SListNodeOfItemLocation_IsNull(t: "opencascade::handle< TopLoc_SListNodeOfItemLocation > const &") -> "bool":
    return _TopLoc.Handle_TopLoc_SListNodeOfItemLocation_IsNull(t)
class TopLoc_IndexedMapOfLocation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def cbegin(self) -> "NCollection_IndexedMap< TopLoc_Location,TopLoc_MapLocationHasher >::const_iterator":
        return _TopLoc.TopLoc_IndexedMapOfLocation_cbegin(self)

    def cend(self) -> "NCollection_IndexedMap< TopLoc_Location,TopLoc_MapLocationHasher >::const_iterator":
        return _TopLoc.TopLoc_IndexedMapOfLocation_cend(self)

    def __init__(self, *args):
        _TopLoc.TopLoc_IndexedMapOfLocation_swiginit(self, _TopLoc.new_TopLoc_IndexedMapOfLocation(*args))

    def Exchange(self, theOther: "TopLoc_IndexedMapOfLocation") -> "void":
        return _TopLoc.TopLoc_IndexedMapOfLocation_Exchange(self, theOther)

    def Assign(self, theOther: "TopLoc_IndexedMapOfLocation") -> "NCollection_IndexedMap< TopLoc_Location,TopLoc_MapLocationHasher > &":
        return _TopLoc.TopLoc_IndexedMapOfLocation_Assign(self, theOther)

    def Set(self, theOther: "TopLoc_IndexedMapOfLocation") -> "NCollection_IndexedMap< TopLoc_Location,TopLoc_MapLocationHasher > &":
        return _TopLoc.TopLoc_IndexedMapOfLocation_Set(self, theOther)

    def ReSize(self, theExtent: "Standard_Integer const") -> "void":
        return _TopLoc.TopLoc_IndexedMapOfLocation_ReSize(self, theExtent)

    def Add(self, theKey1: "TopLoc_Location") -> "Standard_Integer":
        return _TopLoc.TopLoc_IndexedMapOfLocation_Add(self, theKey1)

    def Contains(self, theKey1: "TopLoc_Location") -> "Standard_Boolean":
        return _TopLoc.TopLoc_IndexedMapOfLocation_Contains(self, theKey1)

    def Substitute(self, theIndex: "Standard_Integer const", theKey1: "TopLoc_Location") -> "void":
        return _TopLoc.TopLoc_IndexedMapOfLocation_Substitute(self, theIndex, theKey1)

    def Swap(self, theIndex1: "Standard_Integer const", theIndex2: "Standard_Integer const") -> "void":
        return _TopLoc.TopLoc_IndexedMapOfLocation_Swap(self, theIndex1, theIndex2)

    def RemoveLast(self) -> "void":
        return _TopLoc.TopLoc_IndexedMapOfLocation_RemoveLast(self)

    def RemoveFromIndex(self, theIndex: "Standard_Integer const") -> "void":
        return _TopLoc.TopLoc_IndexedMapOfLocation_RemoveFromIndex(self, theIndex)

    def RemoveKey(self, theKey1: "TopLoc_Location") -> "Standard_Boolean":
        return _TopLoc.TopLoc_IndexedMapOfLocation_RemoveKey(self, theKey1)

    def FindKey(self, theIndex: "Standard_Integer const") -> "TopLoc_Location const &":
        return _TopLoc.TopLoc_IndexedMapOfLocation_FindKey(self, theIndex)

    def __call__(self, theIndex: "Standard_Integer const") -> "TopLoc_Location const &":
        return _TopLoc.TopLoc_IndexedMapOfLocation___call__(self, theIndex)

    def FindIndex(self, theKey1: "TopLoc_Location") -> "Standard_Integer":
        return _TopLoc.TopLoc_IndexedMapOfLocation_FindIndex(self, theKey1)

    def Clear(self, *args) -> "void":
        return _TopLoc.TopLoc_IndexedMapOfLocation_Clear(self, *args)
    __swig_destroy__ = _TopLoc.delete_TopLoc_IndexedMapOfLocation

    def Size(self) -> "Standard_Integer":
        return _TopLoc.TopLoc_IndexedMapOfLocation_Size(self)

# Register TopLoc_IndexedMapOfLocation in _TopLoc:
_TopLoc.TopLoc_IndexedMapOfLocation_swigregister(TopLoc_IndexedMapOfLocation)

class TopLoc_MapLocationHasher(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def HashCode(theKey: "TopLoc_Location", theUpperBound: "Standard_Integer const") -> "Standard_Integer":
        return _TopLoc.TopLoc_MapLocationHasher_HashCode(theKey, theUpperBound)

    @staticmethod
    def IsEqual(theKey1: "TopLoc_Location", theKey2: "TopLoc_Location") -> "Standard_Boolean":
        return _TopLoc.TopLoc_MapLocationHasher_IsEqual(theKey1, theKey2)

    def __init__(self):
        _TopLoc.TopLoc_MapLocationHasher_swiginit(self, _TopLoc.new_TopLoc_MapLocationHasher())
    __swig_destroy__ = _TopLoc.delete_TopLoc_MapLocationHasher

# Register TopLoc_MapLocationHasher in _TopLoc:
_TopLoc.TopLoc_MapLocationHasher_swigregister(TopLoc_MapLocationHasher)

def TopLoc_MapLocationHasher_HashCode(theKey: "TopLoc_Location", theUpperBound: "Standard_Integer const") -> "Standard_Integer":
    return _TopLoc.TopLoc_MapLocationHasher_HashCode(theKey, theUpperBound)

def TopLoc_MapLocationHasher_IsEqual(theKey1: "TopLoc_Location", theKey2: "TopLoc_Location") -> "Standard_Boolean":
    return _TopLoc.TopLoc_MapLocationHasher_IsEqual(theKey1, theKey2)

class TopLoc_MapOfLocation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def cbegin(self) -> "NCollection_Map< TopLoc_Location,TopLoc_MapLocationHasher >::const_iterator":
        return _TopLoc.TopLoc_MapOfLocation_cbegin(self)

    def cend(self) -> "NCollection_Map< TopLoc_Location,TopLoc_MapLocationHasher >::const_iterator":
        return _TopLoc.TopLoc_MapOfLocation_cend(self)

    def __init__(self, *args):
        _TopLoc.TopLoc_MapOfLocation_swiginit(self, _TopLoc.new_TopLoc_MapOfLocation(*args))

    def Exchange(self, theOther: "TopLoc_MapOfLocation") -> "void":
        return _TopLoc.TopLoc_MapOfLocation_Exchange(self, theOther)

    def Assign(self, theOther: "TopLoc_MapOfLocation") -> "NCollection_Map< TopLoc_Location,TopLoc_MapLocationHasher > &":
        return _TopLoc.TopLoc_MapOfLocation_Assign(self, theOther)

    def Set(self, theOther: "TopLoc_MapOfLocation") -> "NCollection_Map< TopLoc_Location,TopLoc_MapLocationHasher > &":
        return _TopLoc.TopLoc_MapOfLocation_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _TopLoc.TopLoc_MapOfLocation_ReSize(self, N)

    def Add(self, K: "TopLoc_Location") -> "Standard_Boolean":
        return _TopLoc.TopLoc_MapOfLocation_Add(self, K)

    def Added(self, K: "TopLoc_Location") -> "TopLoc_Location const &":
        return _TopLoc.TopLoc_MapOfLocation_Added(self, K)

    def Remove(self, K: "TopLoc_Location") -> "Standard_Boolean":
        return _TopLoc.TopLoc_MapOfLocation_Remove(self, K)

    def Clear(self, *args) -> "void":
        return _TopLoc.TopLoc_MapOfLocation_Clear(self, *args)
    __swig_destroy__ = _TopLoc.delete_TopLoc_MapOfLocation

    def Size(self) -> "Standard_Integer":
        return _TopLoc.TopLoc_MapOfLocation_Size(self)

    def IsEqual(self, theOther: "TopLoc_MapOfLocation") -> "Standard_Boolean":
        return _TopLoc.TopLoc_MapOfLocation_IsEqual(self, theOther)

    def Contains(self, *args) -> "Standard_Boolean":
        return _TopLoc.TopLoc_MapOfLocation_Contains(self, *args)

    def Union(self, theLeft: "TopLoc_MapOfLocation", theRight: "TopLoc_MapOfLocation") -> "void":
        return _TopLoc.TopLoc_MapOfLocation_Union(self, theLeft, theRight)

    def Unite(self, theOther: "TopLoc_MapOfLocation") -> "Standard_Boolean":
        return _TopLoc.TopLoc_MapOfLocation_Unite(self, theOther)

    def HasIntersection(self, theMap: "TopLoc_MapOfLocation") -> "Standard_Boolean":
        return _TopLoc.TopLoc_MapOfLocation_HasIntersection(self, theMap)

    def Intersection(self, theLeft: "TopLoc_MapOfLocation", theRight: "TopLoc_MapOfLocation") -> "void":
        return _TopLoc.TopLoc_MapOfLocation_Intersection(self, theLeft, theRight)

    def Intersect(self, theOther: "TopLoc_MapOfLocation") -> "Standard_Boolean":
        return _TopLoc.TopLoc_MapOfLocation_Intersect(self, theOther)

    def Subtraction(self, theLeft: "TopLoc_MapOfLocation", theRight: "TopLoc_MapOfLocation") -> "void":
        return _TopLoc.TopLoc_MapOfLocation_Subtraction(self, theLeft, theRight)

    def Subtract(self, theOther: "TopLoc_MapOfLocation") -> "Standard_Boolean":
        return _TopLoc.TopLoc_MapOfLocation_Subtract(self, theOther)

    def Difference(self, theLeft: "TopLoc_MapOfLocation", theRight: "TopLoc_MapOfLocation") -> "void":
        return _TopLoc.TopLoc_MapOfLocation_Difference(self, theLeft, theRight)

    def Differ(self, theOther: "TopLoc_MapOfLocation") -> "Standard_Boolean":
        return _TopLoc.TopLoc_MapOfLocation_Differ(self, theOther)

# Register TopLoc_MapOfLocation in _TopLoc:
_TopLoc.TopLoc_MapOfLocation_swigregister(TopLoc_MapOfLocation)

class TopLoc_Datum3D(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs a default datum3d.

        Returns
        -------
        None
        Constructs a datum3d form a trsf from gp. an error is raised if the trsf is not a rigid transformation.

        Parameters
        ----------
        T: gp_Trsf

        Returns
        -------
        None

        """
        _TopLoc.TopLoc_Datum3D_swiginit(self, _TopLoc.new_TopLoc_Datum3D(*args))

    def DumpJsonToString(self, depth: "int"=-1) -> "std::string":
        r"""DumpJsonToString(TopLoc_Datum3D self, int depth=-1) -> std::string"""
        return _TopLoc.TopLoc_Datum3D_DumpJsonToString(self, depth)

    def Form(self, *args) -> "gp_TrsfForm":
        r"""
        Return transformation form.

        Returns
        -------
        gp_TrsfForm

        """
        return _TopLoc.TopLoc_Datum3D_Form(self, *args)

    def ShallowDumpToString(self) -> "std::string":
        r"""ShallowDumpToString(TopLoc_Datum3D self) -> std::string"""
        return _TopLoc.TopLoc_Datum3D_ShallowDumpToString(self)

    def Transformation(self, *args) -> "gp_Trsf const":
        r"""
        Returns a gp_trsf which, when applied to this datum, produces the default datum.

        Returns
        -------
        gp_Trsf

        """
        return _TopLoc.TopLoc_Datum3D_Transformation(self, *args)

    def Trsf(self, *args) -> "gp_Trsf const":
        r"""
        Returns a gp_trsf which, when applied to this datum, produces the default datum.

        Returns
        -------
        gp_Trsf

        """
        return _TopLoc.TopLoc_Datum3D_Trsf(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TopLoc_Datum3D_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TopLoc.delete_TopLoc_Datum3D

# Register TopLoc_Datum3D in _TopLoc:
_TopLoc.TopLoc_Datum3D_swigregister(TopLoc_Datum3D)

class TopLoc_ItemLocation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Sets the elementary datum to <d> sets the exponent to <p>.

        Parameters
        ----------
        D: TopLoc_Datum3D
        P: int

        Returns
        -------
        None

        """
        _TopLoc.TopLoc_ItemLocation_swiginit(self, _TopLoc.new_TopLoc_ItemLocation(*args))

    def DumpJsonToString(self, depth: "int"=-1) -> "std::string":
        r"""DumpJsonToString(TopLoc_ItemLocation self, int depth=-1) -> std::string"""
        return _TopLoc.TopLoc_ItemLocation_DumpJsonToString(self, depth)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopLoc.delete_TopLoc_ItemLocation

# Register TopLoc_ItemLocation in _TopLoc:
_TopLoc.TopLoc_ItemLocation_swigregister(TopLoc_ItemLocation)

class TopLoc_Location(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty local coordinate system object. note: a location constructed from a default datum is said to be 'empty'.

        Returns
        -------
        None
        Constructs the local coordinate system object defined by the transformation t. t invokes in turn, a toploc_datum3d object.

        Parameters
        ----------
        T: gp_Trsf

        Returns
        -------
        None
        Constructs the local coordinate system object defined by the 3d datum d. exceptions standard_constructionerror if the transformation t does not represent a 3d coordinate system.

        Parameters
        ----------
        D: TopLoc_Datum3D

        Returns
        -------
        None

        """
        _TopLoc.TopLoc_Location_swiginit(self, _TopLoc.new_TopLoc_Location(*args))

    def Divided(self, *args) -> "TopLoc_Location":
        r"""
        Returns <self> / <other>.

        Parameters
        ----------
        Other: TopLoc_Location

        Returns
        -------
        TopLoc_Location

        """
        return _TopLoc.TopLoc_Location_Divided(self, *args)

    def DumpJsonToString(self, depth: "int"=-1) -> "std::string":
        r"""DumpJsonToString(TopLoc_Location self, int depth=-1) -> std::string"""
        return _TopLoc.TopLoc_Location_DumpJsonToString(self, depth)

    def FirstDatum(self, *args) -> "opencascade::handle< TopLoc_Datum3D > const &":
        r"""
        Returns the first elementary datum of the location. use the nextlocation function recursively to access the other data comprising this location. exceptions standard_nosuchobject if this location is empty.

        Returns
        -------
        opencascade::handle<TopLoc_Datum3D>

        """
        return _TopLoc.TopLoc_Location_FirstDatum(self, *args)

    def FirstPower(self, *args) -> "Standard_Integer":
        r"""
        Returns the power elevation of the first elementary datum. exceptions standard_nosuchobject if this location is empty.

        Returns
        -------
        int

        """
        return _TopLoc.TopLoc_Location_FirstPower(self, *args)

    def HashCode(self, *args) -> "Standard_Integer":
        r"""
        Returns a hashed value for this local coordinate system. this value is used, with map tables, to store and retrieve the object easily, and is in the range [1, theupperbound]. @param theupperbound the upper bound of the range a computing hash code must be within returns a computed hash code, in the range [1, theupperbound].

        Parameters
        ----------
        theUpperBound: int

        Returns
        -------
        int

        """
        return _TopLoc.TopLoc_Location_HashCode(self, *args)

    def __hash__(self) -> "Standard_Integer":
        r"""__hash__(TopLoc_Location self) -> Standard_Integer"""
        return _TopLoc.TopLoc_Location___hash__(self)

    def Identity(self, *args) -> "void":
        r"""
        Resets this location to the identity transformation.

        Returns
        -------
        None

        """
        return _TopLoc.TopLoc_Location_Identity(self, *args)

    def Inverted(self, *args) -> "TopLoc_Location":
        r"""
        Returns the inverse of <self>. //! <self> * inverted() is an identity.

        Returns
        -------
        TopLoc_Location

        """
        return _TopLoc.TopLoc_Location_Inverted(self, *args)

    def IsDifferent(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this location and the location other do not have the same elementary data, i.e. do not contain the same series of toploc_datum3d and respective powers. this method is an alias for operator !=.

        Parameters
        ----------
        Other: TopLoc_Location

        Returns
        -------
        bool

        """
        return _TopLoc.TopLoc_Location_IsDifferent(self, *args)

    def IsEqual(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this location and the location other have the same elementary data, i.e. contain the same series of toploc_datum3d and respective powers. this method is an alias for operator ==.

        Parameters
        ----------
        Other: TopLoc_Location

        Returns
        -------
        bool

        """
        return _TopLoc.TopLoc_Location_IsEqual(self, *args)

    def IsIdentity(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this location is equal to the identity transformation.

        Returns
        -------
        bool

        """
        return _TopLoc.TopLoc_Location_IsIdentity(self, *args)

    def Multiplied(self, *args) -> "TopLoc_Location":
        r"""
        Returns <self> * <other>, the elementary datums are concatenated.

        Parameters
        ----------
        Other: TopLoc_Location

        Returns
        -------
        TopLoc_Location

        """
        return _TopLoc.TopLoc_Location_Multiplied(self, *args)

    def NextLocation(self, *args) -> "TopLoc_Location const &":
        r"""
        Returns a location representing <self> without the first datum. we have the relation : //! <self> = nextlocation() * firstdatum() ^ firstpower() exceptions standard_nosuchobject if this location is empty.

        Returns
        -------
        TopLoc_Location

        """
        return _TopLoc.TopLoc_Location_NextLocation(self, *args)

    def Powered(self, *args) -> "TopLoc_Location":
        r"""
        Returns me at the power <pwr>. if <pwr> is zero returns identity. <pwr> can be lower than zero (usual meaning for powers).

        Parameters
        ----------
        pwr: int

        Returns
        -------
        TopLoc_Location

        """
        return _TopLoc.TopLoc_Location_Powered(self, *args)

    def Predivided(self, *args) -> "TopLoc_Location":
        r"""
        Returns <other>.inverted() * <self>.

        Parameters
        ----------
        Other: TopLoc_Location

        Returns
        -------
        TopLoc_Location

        """
        return _TopLoc.TopLoc_Location_Predivided(self, *args)

    def ShallowDumpToString(self) -> "std::string":
        r"""ShallowDumpToString(TopLoc_Location self) -> std::string"""
        return _TopLoc.TopLoc_Location_ShallowDumpToString(self)

    def Transformation(self, *args) -> "gp_Trsf const":
        r"""
        Returns the transformation associated to the coordinate system.

        Returns
        -------
        gp_Trsf

        """
        return _TopLoc.TopLoc_Location_Transformation(self, *args)

    def __ne_wrapper__(self, other: "TopLoc_Location") -> "bool":
        r"""__ne_wrapper__(TopLoc_Location self, TopLoc_Location other) -> bool"""
        return _TopLoc.TopLoc_Location___ne_wrapper__(self, other)

    def __ne__(self, right):
        try:
            return self.__ne_wrapper__(right)
        except:
            return True


    def __mul__(self, *args) -> "TopLoc_Location":
        r"""
        No available documentation.

        Parameters
        ----------
        Other: TopLoc_Location

        Returns
        -------
        TopLoc_Location

        """
        return _TopLoc.TopLoc_Location___mul__(self, *args)

    def __truediv__(self, *args):
        return _TopLoc.TopLoc_Location___truediv__(self, *args)
    __div__ = __truediv__



    def __eq_wrapper__(self, other: "TopLoc_Location") -> "bool":
        r"""__eq_wrapper__(TopLoc_Location self, TopLoc_Location other) -> bool"""
        return _TopLoc.TopLoc_Location___eq_wrapper__(self, other)

    def __eq__(self, right):
        try:
            return self.__eq_wrapper__(right)
        except:
            return False


    __repr__ = _dumps_object

    __swig_destroy__ = _TopLoc.delete_TopLoc_Location

# Register TopLoc_Location in _TopLoc:
_TopLoc.TopLoc_Location_swigregister(TopLoc_Location)

class TopLoc_SListNodeOfItemLocation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        I: TopLoc_ItemLocation
        aTail: TopLoc_SListOfItemLocation

        Returns
        -------
        None

        """
        _TopLoc.TopLoc_SListNodeOfItemLocation_swiginit(self, _TopLoc.new_TopLoc_SListNodeOfItemLocation(*args))

    def Tail(self, *args) -> "TopLoc_SListOfItemLocation &":
        r"""
        No available documentation.

        Returns
        -------
        TopLoc_SListOfItemLocation

        """
        return _TopLoc.TopLoc_SListNodeOfItemLocation_Tail(self, *args)

    def Value(self, *args) -> "TopLoc_ItemLocation &":
        r"""
        No available documentation.

        Returns
        -------
        TopLoc_ItemLocation

        """
        return _TopLoc.TopLoc_SListNodeOfItemLocation_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TopLoc_SListNodeOfItemLocation_DownCast(t)


    __repr__ = _dumps_object

    @methodnotwrapped
    def Count(self):
    	pass

    __swig_destroy__ = _TopLoc.delete_TopLoc_SListNodeOfItemLocation

# Register TopLoc_SListNodeOfItemLocation in _TopLoc:
_TopLoc.TopLoc_SListNodeOfItemLocation_swigregister(TopLoc_SListNodeOfItemLocation)

class TopLoc_SListOfItemLocation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an empty list.

        Returns
        -------
        None
        Creates a list with <anitem> as value and <atail> as tail.

        Parameters
        ----------
        anItem: TopLoc_ItemLocation
        aTail: TopLoc_SListOfItemLocation

        Returns
        -------
        None
        Creates a list from an other one. the lists are shared.

        Parameters
        ----------
        Other: TopLoc_SListOfItemLocation

        Returns
        -------
        None
        Move constructor.

        Parameters
        ----------
        theOther: TopLoc_SListOfItemLocation

        Returns
        -------
        None

        """
        _TopLoc.TopLoc_SListOfItemLocation_swiginit(self, _TopLoc.new_TopLoc_SListOfItemLocation(*args))

    def Assign(self, *args) -> "TopLoc_SListOfItemLocation &":
        r"""
        Sets a list from an other one. the lists are shared. the list itself is returned.

        Parameters
        ----------
        Other: TopLoc_SListOfItemLocation

        Returns
        -------
        TopLoc_SListOfItemLocation

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Assign(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        Sets the list to be empty.

        Returns
        -------
        None

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Clear(self, *args)

    def Construct(self, *args) -> "void":
        r"""
        Replaces the list by a list with <anitem> as value and the list <self> as tail.

        Parameters
        ----------
        anItem: TopLoc_ItemLocation

        Returns
        -------
        None

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Construct(self, *args)

    def IsEmpty(self, *args) -> "Standard_Boolean":
        r"""
        Returne true if this list is empty.

        Returns
        -------
        bool

        """
        return _TopLoc.TopLoc_SListOfItemLocation_IsEmpty(self, *args)

    def More(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the iterator has a current value. this is !isempty().

        Returns
        -------
        bool

        """
        return _TopLoc.TopLoc_SListOfItemLocation_More(self, *args)

    def Next(self, *args) -> "void":
        r"""
        Moves the iterator to the next object in the list. if the iterator is empty it will stay empty. this is totail().

        Returns
        -------
        None

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Next(self, *args)

    def Tail(self, *args) -> "TopLoc_SListOfItemLocation const &":
        r"""
        Returns the current tail of the list. on an empty list the tail is the list itself.

        Returns
        -------
        TopLoc_SListOfItemLocation

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Tail(self, *args)

    def ToTail(self, *args) -> "void":
        r"""
        Replaces the list <self> by its tail.

        Returns
        -------
        None

        """
        return _TopLoc.TopLoc_SListOfItemLocation_ToTail(self, *args)

    def Value(self, *args) -> "TopLoc_ItemLocation const &":
        r"""
        Returns the current value of the list. an error is raised if the list is empty.

        Returns
        -------
        TopLoc_ItemLocation

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopLoc.delete_TopLoc_SListOfItemLocation

# Register TopLoc_SListOfItemLocation in _TopLoc:
_TopLoc.TopLoc_SListOfItemLocation_swigregister(TopLoc_SListOfItemLocation)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Adaptor2d import *
from OCC.Core.TopOpeBRepDS import *
from OCC.Core.ChFiDS import *
from OCC.Core.Adaptor3d import *
from OCC.Core.TopAbs import *
from OCC.Core.gp import *
from OCC.Core.Geom import *
from OCC.Core.Geom2d import *
from OCC.Core.GeomAdaptor import *


class ChFiKPart_ComputeData:
	@staticmethod
	def Compute(DStr: TopOpeBRepDS_DataStructure, Data: ChFiDS_SurfData, S1: Adaptor3d_HSurface, S2: Adaptor3d_HSurface, Or1: TopAbs_Orientation, Or2: TopAbs_Orientation, Sp: ChFiDS_Spine, Iedge: int) -> bool: ...
	@overload
	@staticmethod
	def ComputeCorner(DStr: TopOpeBRepDS_DataStructure, Data: ChFiDS_SurfData, S1: Adaptor3d_HSurface, S2: Adaptor3d_HSurface, OrFace1: TopAbs_Orientation, OrFace2: TopAbs_Orientation, Or1: TopAbs_Orientation, Or2: TopAbs_Orientation, minRad: float, majRad: float, P1S1: gp_Pnt2d, P2S1: gp_Pnt2d, P1S2: gp_Pnt2d, P2S2: gp_Pnt2d) -> bool: ...
	@overload
	@staticmethod
	def ComputeCorner(DStr: TopOpeBRepDS_DataStructure, Data: ChFiDS_SurfData, S1: Adaptor3d_HSurface, S2: Adaptor3d_HSurface, OrFace1: TopAbs_Orientation, OrFace2: TopAbs_Orientation, Or1: TopAbs_Orientation, Or2: TopAbs_Orientation, Rad: float, PS1: gp_Pnt2d, P1S2: gp_Pnt2d, P2S2: gp_Pnt2d) -> bool: ...
	@overload
	@staticmethod
	def ComputeCorner(DStr: TopOpeBRepDS_DataStructure, Data: ChFiDS_SurfData, S: Adaptor3d_HSurface, S1: Adaptor3d_HSurface, S2: Adaptor3d_HSurface, OfS: TopAbs_Orientation, OS: TopAbs_Orientation, OS1: TopAbs_Orientation, OS2: TopAbs_Orientation, Radius: float) -> bool: ...

# harray1 classes
# harray2 classes
# hsequence classes

ChFiKPart_ComputeData_Compute = ChFiKPart_ComputeData.Compute
ChFiKPart_ComputeData_ComputeCorner = ChFiKPart_ComputeData.ComputeCorner
ChFiKPart_ComputeData_ComputeCorner = ChFiKPart_ComputeData.ComputeCorner
ChFiKPart_ComputeData_ComputeCorner = ChFiKPart_ComputeData.ComputeCorner



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
TColGeom2d module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_tcolgeom2d.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TColGeom2d
else:
    import _TColGeom2d

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TColGeom2d.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _TColGeom2d.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TColGeom2d.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TColGeom2d.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _TColGeom2d.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _TColGeom2d.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _TColGeom2d.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _TColGeom2d.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _TColGeom2d.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _TColGeom2d.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TColGeom2d.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _TColGeom2d.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _TColGeom2d.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TColGeom2d.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TColGeom2d.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TColGeom2d.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _TColGeom2d.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TColGeom2d:
_TColGeom2d.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _TColGeom2d.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom2d
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_TColGeom2d_HArray1OfCurve_Create() -> "opencascade::handle< TColGeom2d_HArray1OfCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfCurve_Create()

def Handle_TColGeom2d_HArray1OfCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom2d_HArray1OfCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfCurve_DownCast(t)

def Handle_TColGeom2d_HArray1OfCurve_IsNull(t: "opencascade::handle< TColGeom2d_HArray1OfCurve > const &") -> "bool":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfCurve_IsNull(t)

def Handle_TColGeom2d_HArray1OfBezierCurve_Create() -> "opencascade::handle< TColGeom2d_HArray1OfBezierCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBezierCurve_Create()

def Handle_TColGeom2d_HArray1OfBezierCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom2d_HArray1OfBezierCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBezierCurve_DownCast(t)

def Handle_TColGeom2d_HArray1OfBezierCurve_IsNull(t: "opencascade::handle< TColGeom2d_HArray1OfBezierCurve > const &") -> "bool":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBezierCurve_IsNull(t)

def Handle_TColGeom2d_HArray1OfBSplineCurve_Create() -> "opencascade::handle< TColGeom2d_HArray1OfBSplineCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBSplineCurve_Create()

def Handle_TColGeom2d_HArray1OfBSplineCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom2d_HArray1OfBSplineCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBSplineCurve_DownCast(t)

def Handle_TColGeom2d_HArray1OfBSplineCurve_IsNull(t: "opencascade::handle< TColGeom2d_HArray1OfBSplineCurve > const &") -> "bool":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBSplineCurve_IsNull(t)

def Handle_TColGeom2d_HSequenceOfBoundedCurve_Create() -> "opencascade::handle< TColGeom2d_HSequenceOfBoundedCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfBoundedCurve_Create()

def Handle_TColGeom2d_HSequenceOfBoundedCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom2d_HSequenceOfBoundedCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfBoundedCurve_DownCast(t)

def Handle_TColGeom2d_HSequenceOfBoundedCurve_IsNull(t: "opencascade::handle< TColGeom2d_HSequenceOfBoundedCurve > const &") -> "bool":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfBoundedCurve_IsNull(t)

def Handle_TColGeom2d_HSequenceOfCurve_Create() -> "opencascade::handle< TColGeom2d_HSequenceOfCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfCurve_Create()

def Handle_TColGeom2d_HSequenceOfCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom2d_HSequenceOfCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfCurve_DownCast(t)

def Handle_TColGeom2d_HSequenceOfCurve_IsNull(t: "opencascade::handle< TColGeom2d_HSequenceOfCurve > const &") -> "bool":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfCurve_IsNull(t)
class TColGeom2d_Array1OfBSplineCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_Array1OfBSplineCurve(*args))

    def Init(self, theValue: "opencascade::handle< Geom2d_BSplineCurve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_IsAllocated(self)

    def Assign(self, theOther: "TColGeom2d_Array1OfBSplineCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Assign(self, theOther)

    def Move(self, theOther: "TColGeom2d_Array1OfBSplineCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Set(self, *args)

    def First(self) -> "opencascade::handle< Geom2d_BSplineCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_BSplineCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_BSplineCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_BSplineCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BSplineCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BSplineCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_BSplineCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_BSplineCurve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_Array1OfBSplineCurve

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register TColGeom2d_Array1OfBSplineCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_Array1OfBSplineCurve_swigregister(TColGeom2d_Array1OfBSplineCurve)

class TColGeom2d_Array1OfBezierCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_Array1OfBezierCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_Array1OfBezierCurve(*args))

    def Init(self, theValue: "opencascade::handle< Geom2d_BezierCurve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_IsAllocated(self)

    def Assign(self, theOther: "TColGeom2d_Array1OfBezierCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Assign(self, theOther)

    def Move(self, theOther: "TColGeom2d_Array1OfBezierCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Set(self, *args)

    def First(self) -> "opencascade::handle< Geom2d_BezierCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_BezierCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_BezierCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_BezierCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BezierCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BezierCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_BezierCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_BezierCurve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_Array1OfBezierCurve

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register TColGeom2d_Array1OfBezierCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_Array1OfBezierCurve_swigregister(TColGeom2d_Array1OfBezierCurve)

class TColGeom2d_Array1OfCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_Array1OfCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_Array1OfCurve(*args))

    def Init(self, theValue: "opencascade::handle< Geom2d_Curve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_IsAllocated(self)

    def Assign(self, theOther: "TColGeom2d_Array1OfCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Assign(self, theOther)

    def Move(self, theOther: "TColGeom2d_Array1OfCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Set(self, *args)

    def First(self) -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_Curve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_Array1OfCurve

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register TColGeom2d_Array1OfCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_Array1OfCurve_swigregister(TColGeom2d_Array1OfCurve)

class TColGeom2d_SequenceOfBoundedCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_SequenceOfBoundedCurve(*args))

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_IsEmpty(self)

    def Reverse(self) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Clear(self, theAllocator)

    def Assign(self, theOther: "TColGeom2d_SequenceOfBoundedCurve") -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Assign(self, theOther)

    def Set(self, theOther: "TColGeom2d_SequenceOfBoundedCurve") -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "TColGeom2d_SequenceOfBoundedCurve") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Geom2d_BoundedCurve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_BoundedCurve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_BoundedCurve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_BoundedCurve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BoundedCurve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BoundedCurve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_BoundedCurve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_BoundedCurve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_SequenceOfBoundedCurve

    def __len__(self):
        return self.Size()


# Register TColGeom2d_SequenceOfBoundedCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_swigregister(TColGeom2d_SequenceOfBoundedCurve)

def TColGeom2d_SequenceOfBoundedCurve_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_delNode(theNode, theAl)

class TColGeom2d_SequenceOfCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_SequenceOfCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_SequenceOfCurve(*args))

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_IsEmpty(self)

    def Reverse(self) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Clear(self, theAllocator)

    def Assign(self, theOther: "TColGeom2d_SequenceOfCurve") -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Assign(self, theOther)

    def Set(self, theOther: "TColGeom2d_SequenceOfCurve") -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "TColGeom2d_SequenceOfCurve") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_Curve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_SequenceOfCurve

    def __len__(self):
        return self.Size()


# Register TColGeom2d_SequenceOfCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_SequenceOfCurve_swigregister(TColGeom2d_SequenceOfCurve)

def TColGeom2d_SequenceOfCurve_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _TColGeom2d.TColGeom2d_SequenceOfCurve_delNode(theNode, theAl)

class TColGeom2d_SequenceOfGeometry(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_SequenceOfGeometry_swiginit(self, _TColGeom2d.new_TColGeom2d_SequenceOfGeometry(*args))

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_IsEmpty(self)

    def Reverse(self) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Clear(self, theAllocator)

    def Assign(self, theOther: "TColGeom2d_SequenceOfGeometry") -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Assign(self, theOther)

    def Set(self, theOther: "TColGeom2d_SequenceOfGeometry") -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "TColGeom2d_SequenceOfGeometry") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Geom2d_Geometry > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_Geometry > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_Geometry > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_Geometry > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Geometry > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Geometry > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_Geometry > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_Geometry > const &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_SequenceOfGeometry

    def __len__(self):
        return self.Size()


# Register TColGeom2d_SequenceOfGeometry in _TColGeom2d:
_TColGeom2d.TColGeom2d_SequenceOfGeometry_swigregister(TColGeom2d_SequenceOfGeometry)

def TColGeom2d_SequenceOfGeometry_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _TColGeom2d.TColGeom2d_SequenceOfGeometry_delNode(theNode, theAl)

class TColGeom2d_HArray1OfCurve(TColGeom2d_Array1OfCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_HArray1OfCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_HArray1OfCurve(*args))

    def Array1(self) -> "TColGeom2d_Array1OfCurve const &":
        return _TColGeom2d.TColGeom2d_HArray1OfCurve_Array1(self)

    def ChangeArray1(self) -> "TColGeom2d_Array1OfCurve &":
        return _TColGeom2d.TColGeom2d_HArray1OfCurve_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom2d_HArray1OfCurve_DownCast(t)

    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_HArray1OfCurve

# Register TColGeom2d_HArray1OfCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_HArray1OfCurve_swigregister(TColGeom2d_HArray1OfCurve)

class TColGeom2d_HArray1OfBezierCurve(TColGeom2d_Array1OfBezierCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_HArray1OfBezierCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_HArray1OfBezierCurve(*args))

    def Array1(self) -> "TColGeom2d_Array1OfBezierCurve const &":
        return _TColGeom2d.TColGeom2d_HArray1OfBezierCurve_Array1(self)

    def ChangeArray1(self) -> "TColGeom2d_Array1OfBezierCurve &":
        return _TColGeom2d.TColGeom2d_HArray1OfBezierCurve_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom2d_HArray1OfBezierCurve_DownCast(t)

    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_HArray1OfBezierCurve

# Register TColGeom2d_HArray1OfBezierCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_HArray1OfBezierCurve_swigregister(TColGeom2d_HArray1OfBezierCurve)

class TColGeom2d_HArray1OfBSplineCurve(TColGeom2d_Array1OfBSplineCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_HArray1OfBSplineCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_HArray1OfBSplineCurve(*args))

    def Array1(self) -> "TColGeom2d_Array1OfBSplineCurve const &":
        return _TColGeom2d.TColGeom2d_HArray1OfBSplineCurve_Array1(self)

    def ChangeArray1(self) -> "TColGeom2d_Array1OfBSplineCurve &":
        return _TColGeom2d.TColGeom2d_HArray1OfBSplineCurve_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom2d_HArray1OfBSplineCurve_DownCast(t)

    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_HArray1OfBSplineCurve

# Register TColGeom2d_HArray1OfBSplineCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_HArray1OfBSplineCurve_swigregister(TColGeom2d_HArray1OfBSplineCurve)

class TColGeom2d_HSequenceOfBoundedCurve(TColGeom2d_SequenceOfBoundedCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_HSequenceOfBoundedCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_HSequenceOfBoundedCurve(*args))

    def Sequence(self) -> "TColGeom2d_SequenceOfBoundedCurve const &":
        return _TColGeom2d.TColGeom2d_HSequenceOfBoundedCurve_Sequence(self)

    def Append(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_HSequenceOfBoundedCurve_Append(self, *args)

    def ChangeSequence(self) -> "TColGeom2d_SequenceOfBoundedCurve &":
        return _TColGeom2d.TColGeom2d_HSequenceOfBoundedCurve_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom2d_HSequenceOfBoundedCurve_DownCast(t)

    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_HSequenceOfBoundedCurve

# Register TColGeom2d_HSequenceOfBoundedCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_HSequenceOfBoundedCurve_swigregister(TColGeom2d_HSequenceOfBoundedCurve)

class TColGeom2d_HSequenceOfCurve(TColGeom2d_SequenceOfCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_HSequenceOfCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_HSequenceOfCurve(*args))

    def Sequence(self) -> "TColGeom2d_SequenceOfCurve const &":
        return _TColGeom2d.TColGeom2d_HSequenceOfCurve_Sequence(self)

    def Append(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_HSequenceOfCurve_Append(self, *args)

    def ChangeSequence(self) -> "TColGeom2d_SequenceOfCurve &":
        return _TColGeom2d.TColGeom2d_HSequenceOfCurve_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom2d_HSequenceOfCurve_DownCast(t)

    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_HSequenceOfCurve

# Register TColGeom2d_HSequenceOfCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_HSequenceOfCurve_swigregister(TColGeom2d_HSequenceOfCurve)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
StlAPI module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_stlapi.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _StlAPI
else:
    import _StlAPI

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _StlAPI.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _StlAPI.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StlAPI.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StlAPI.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _StlAPI.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _StlAPI.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _StlAPI.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _StlAPI.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _StlAPI.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _StlAPI.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StlAPI.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _StlAPI.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _StlAPI.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StlAPI.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StlAPI.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StlAPI.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _StlAPI.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _StlAPI:
_StlAPI.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _StlAPI.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp

from enum import IntEnum
from OCC.Core.Exception import *



class stlapi(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Read(*args) -> "Standard_Boolean":
        r"""
        Legacy interface. read stl file and create a shape composed of triangular faces, one per facet. this approach is very inefficient, especially for large files. consider reading stl file to poly_triangulation object instead (see class rwstl).

        Parameters
        ----------
        theShape: TopoDS_Shape
        aFile: char *

        Returns
        -------
        bool

        """
        return _StlAPI.stlapi_Read(*args)

    @staticmethod
    def Write(*args) -> "Standard_Boolean":
        r"""
        Convert and write shape to stl format. file is written in binary if aasciimode is false otherwise it is written in ascii (by default).

        Parameters
        ----------
        theShape: TopoDS_Shape
        theFile: char *
        theAsciiMode: bool,optional
        	default value is Standard_True

        Returns
        -------
        bool

        """
        return _StlAPI.stlapi_Write(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _StlAPI.stlapi_swiginit(self, _StlAPI.new_stlapi())
    __swig_destroy__ = _StlAPI.delete_stlapi

# Register stlapi in _StlAPI:
_StlAPI.stlapi_swigregister(stlapi)

def stlapi_Read(*args) -> "Standard_Boolean":
    r"""
    Legacy interface. read stl file and create a shape composed of triangular faces, one per facet. this approach is very inefficient, especially for large files. consider reading stl file to poly_triangulation object instead (see class rwstl).

    Parameters
    ----------
    theShape: TopoDS_Shape
    aFile: char *

    Returns
    -------
    bool

    """
    return _StlAPI.stlapi_Read(*args)

def stlapi_Write(*args) -> "Standard_Boolean":
    r"""
    Convert and write shape to stl format. file is written in binary if aasciimode is false otherwise it is written in ascii (by default).

    Parameters
    ----------
    theShape: TopoDS_Shape
    theFile: char *
    theAsciiMode: bool,optional
    	default value is Standard_True

    Returns
    -------
    bool

    """
    return _StlAPI.stlapi_Write(*args)

class StlAPI_Reader(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def Read(self, *args) -> "Standard_Boolean":
        r"""
        Reads stl file to the topods_shape (each triangle is converted to the face). returns true if reading is successful.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theFileName: char *

        Returns
        -------
        bool

        """
        return _StlAPI.StlAPI_Reader_Read(self, *args)

    __repr__ = _dumps_object


    def __init__(self):
        _StlAPI.StlAPI_Reader_swiginit(self, _StlAPI.new_StlAPI_Reader())
    __swig_destroy__ = _StlAPI.delete_StlAPI_Reader

# Register StlAPI_Reader in _StlAPI:
_StlAPI.StlAPI_Reader_swigregister(StlAPI_Reader)

class StlAPI_Writer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a writer object with default parameters: asciimode.

        Returns
        -------
        None

        """
        _StlAPI.StlAPI_Writer_swiginit(self, _StlAPI.new_StlAPI_Writer(*args))

    def GetASCIIMode(self) -> "Standard_Boolean":
        r"""GetASCIIMode(StlAPI_Writer self) -> Standard_Boolean"""
        return _StlAPI.StlAPI_Writer_GetASCIIMode(self)

    def SetASCIIMode(self, value: "Standard_Boolean") -> "void":
        r"""SetASCIIMode(StlAPI_Writer self, Standard_Boolean value)"""
        return _StlAPI.StlAPI_Writer_SetASCIIMode(self, value)

    def Write(self, *args) -> "Standard_Boolean":
        r"""
        Converts a given shape to stl format and writes it to file with a given filename. eturn the error state.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theFileName: char *
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _StlAPI.StlAPI_Writer_Write(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StlAPI.delete_StlAPI_Writer

# Register StlAPI_Writer in _StlAPI:
_StlAPI.StlAPI_Writer_swigregister(StlAPI_Writer)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepClass3d module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_brepclass3d.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepClass3d
else:
    import _BRepClass3d

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepClass3d.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepClass3d.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepClass3d.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepClass3d.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepClass3d.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepClass3d.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepClass3d.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepClass3d.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepClass3d.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepClass3d.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepClass3d.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepClass3d.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepClass3d.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepClass3d.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepClass3d.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepClass3d.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepClass3d.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepClass3d:
_BRepClass3d.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepClass3d.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.IntCurveSurface
import OCC.Core.math
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.Intf
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.IntSurf
import OCC.Core.TopTools
import OCC.Core.IntCurvesFace
import OCC.Core.BRepAdaptor
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor

from enum import IntEnum
from OCC.Core.Exception import *



class BRepClass3d_BndBoxTree(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _BRepClass3d.BRepClass3d_BndBoxTree_swiginit(self, _BRepClass3d.new_BRepClass3d_BndBoxTree(*args))

    def Add(self, theObj: "int const &", theBnd: "Bnd_Box") -> "Standard_Boolean":
        return _BRepClass3d.BRepClass3d_BndBoxTree_Add(self, theObj, theBnd)

    def Select(self, theSelector: "NCollection_UBTree< int,Bnd_Box >::Selector &") -> "Standard_Integer":
        return _BRepClass3d.BRepClass3d_BndBoxTree_Select(self, theSelector)

    def Clear(self, aNewAlloc: "IntSurf_Allocator"=0) -> "void":
        return _BRepClass3d.BRepClass3d_BndBoxTree_Clear(self, aNewAlloc)

    def IsEmpty(self) -> "Standard_Boolean":
        return _BRepClass3d.BRepClass3d_BndBoxTree_IsEmpty(self)

    def Root(self) -> "NCollection_UBTree< int,Bnd_Box >::TreeNode const &":
        return _BRepClass3d.BRepClass3d_BndBoxTree_Root(self)
    __swig_destroy__ = _BRepClass3d.delete_BRepClass3d_BndBoxTree

    def Allocator(self) -> "opencascade::handle< NCollection_BaseAllocator > const &":
        return _BRepClass3d.BRepClass3d_BndBoxTree_Allocator(self)

# Register BRepClass3d_BndBoxTree in _BRepClass3d:
_BRepClass3d.BRepClass3d_BndBoxTree_swigregister(BRepClass3d_BndBoxTree)

class BRepClass3d_MapOfInter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_DataMap< TopoDS_Shape,void *,TopTools_ShapeMapHasher >::iterator":
        return _BRepClass3d.BRepClass3d_MapOfInter_begin(self)

    def end(self) -> "NCollection_DataMap< TopoDS_Shape,void *,TopTools_ShapeMapHasher >::iterator":
        return _BRepClass3d.BRepClass3d_MapOfInter_end(self)

    def cbegin(self) -> "NCollection_DataMap< TopoDS_Shape,void *,TopTools_ShapeMapHasher >::const_iterator":
        return _BRepClass3d.BRepClass3d_MapOfInter_cbegin(self)

    def cend(self) -> "NCollection_DataMap< TopoDS_Shape,void *,TopTools_ShapeMapHasher >::const_iterator":
        return _BRepClass3d.BRepClass3d_MapOfInter_cend(self)

    def __init__(self, *args):
        _BRepClass3d.BRepClass3d_MapOfInter_swiginit(self, _BRepClass3d.new_BRepClass3d_MapOfInter(*args))

    def Exchange(self, theOther: "BRepClass3d_MapOfInter") -> "void":
        return _BRepClass3d.BRepClass3d_MapOfInter_Exchange(self, theOther)

    def Assign(self, theOther: "BRepClass3d_MapOfInter") -> "NCollection_DataMap< TopoDS_Shape,void *,TopTools_ShapeMapHasher > &":
        return _BRepClass3d.BRepClass3d_MapOfInter_Assign(self, theOther)

    def Set(self, theOther: "BRepClass3d_MapOfInter") -> "NCollection_DataMap< TopoDS_Shape,void *,TopTools_ShapeMapHasher > &":
        return _BRepClass3d.BRepClass3d_MapOfInter_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _BRepClass3d.BRepClass3d_MapOfInter_ReSize(self, N)

    def Bind(self, theKey: "TopoDS_Shape", theItem: "void *const &") -> "Standard_Boolean":
        return _BRepClass3d.BRepClass3d_MapOfInter_Bind(self, theKey, theItem)

    def Bound(self, theKey: "TopoDS_Shape", theItem: "void *const &") -> "void **":
        return _BRepClass3d.BRepClass3d_MapOfInter_Bound(self, theKey, theItem)

    def IsBound(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _BRepClass3d.BRepClass3d_MapOfInter_IsBound(self, theKey)

    def UnBind(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _BRepClass3d.BRepClass3d_MapOfInter_UnBind(self, theKey)

    def Seek(self, theKey: "TopoDS_Shape") -> "void *const *":
        return _BRepClass3d.BRepClass3d_MapOfInter_Seek(self, theKey)

    def Find(self, *args) -> "Standard_Boolean":
        return _BRepClass3d.BRepClass3d_MapOfInter_Find(self, *args)

    def ChangeSeek(self, theKey: "TopoDS_Shape") -> "void **":
        return _BRepClass3d.BRepClass3d_MapOfInter_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey: "TopoDS_Shape") -> "void *&":
        return _BRepClass3d.BRepClass3d_MapOfInter_ChangeFind(self, theKey)

    def __call__(self, *args) -> "void *&":
        return _BRepClass3d.BRepClass3d_MapOfInter___call__(self, *args)

    def Clear(self, *args) -> "void":
        return _BRepClass3d.BRepClass3d_MapOfInter_Clear(self, *args)
    __swig_destroy__ = _BRepClass3d.delete_BRepClass3d_MapOfInter

    def Size(self) -> "Standard_Integer":
        return _BRepClass3d.BRepClass3d_MapOfInter_Size(self)

# Register BRepClass3d_MapOfInter in _BRepClass3d:
_BRepClass3d.BRepClass3d_MapOfInter_swigregister(BRepClass3d_MapOfInter)

class brepclass3d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def OuterShell(*args) -> "TopoDS_Shell":
        r"""
        Returns the outer most shell of <s>. returns a null shell if <s> has no outer shell. if <s> has only one shell, then it will return, without checking orientation.

        Parameters
        ----------
        S: TopoDS_Solid

        Returns
        -------
        TopoDS_Shell

        """
        return _BRepClass3d.brepclass3d_OuterShell(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _BRepClass3d.brepclass3d_swiginit(self, _BRepClass3d.new_brepclass3d())
    __swig_destroy__ = _BRepClass3d.delete_brepclass3d

# Register brepclass3d in _BRepClass3d:
_BRepClass3d.brepclass3d_swigregister(brepclass3d)

def brepclass3d_OuterShell(*args) -> "TopoDS_Shell":
    r"""
    Returns the outer most shell of <s>. returns a null shell if <s> has no outer shell. if <s> has only one shell, then it will return, without checking orientation.

    Parameters
    ----------
    S: TopoDS_Solid

    Returns
    -------
    TopoDS_Shell

    """
    return _BRepClass3d.brepclass3d_OuterShell(*args)

class BRepClass3d_Intersector3d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _BRepClass3d.BRepClass3d_Intersector3d_swiginit(self, _BRepClass3d.new_BRepClass3d_Intersector3d(*args))

    def Face(self, *args) -> "TopoDS_Face const":
        r"""
        Returns the significant face used to determine the intersection.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepClass3d.BRepClass3d_Intersector3d_Face(self, *args)

    def HasAPoint(self, *args) -> "Standard_Boolean":
        r"""
        True is returned if a point has been found.

        Returns
        -------
        bool

        """
        return _BRepClass3d.BRepClass3d_Intersector3d_HasAPoint(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        True is returned when the intersection have been computed.

        Returns
        -------
        bool

        """
        return _BRepClass3d.BRepClass3d_Intersector3d_IsDone(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Perform the intersection between the segment l(0) ... l(prm) and the shape <sh>. //! only the point with the smallest parameter on the line is returned. //! the tolerance <tol> is used to determine if the first point of the segment is near the face. in that case, the parameter of the intersection point on the line can be a negative value (greater than -tol).

        Parameters
        ----------
        L: gp_Lin
        Prm: float
        Tol: float
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_Intersector3d_Perform(self, *args)

    def Pnt(self, *args) -> "gp_Pnt const":
        r"""
        Returns the geometric point of the intersection between the line and the surface.

        Returns
        -------
        gp_Pnt

        """
        return _BRepClass3d.BRepClass3d_Intersector3d_Pnt(self, *args)

    def State(self, *args) -> "TopAbs_State":
        r"""
        Returns the state of the point on the face. the values can be either topabs_in ( the point is in the face) or topabs_on ( the point is on a boudary of the face).

        Returns
        -------
        TopAbs_State

        """
        return _BRepClass3d.BRepClass3d_Intersector3d_State(self, *args)

    def Transition(self, *args) -> "IntCurveSurface_TransitionOnCurve":
        r"""
        Returns the transition of the line on the surface.

        Returns
        -------
        IntCurveSurface_TransitionOnCurve

        """
        return _BRepClass3d.BRepClass3d_Intersector3d_Transition(self, *args)

    def UParameter(self, *args) -> "Standard_Real":
        r"""
        Returns the u parameter of the intersection point on the surface.

        Returns
        -------
        float

        """
        return _BRepClass3d.BRepClass3d_Intersector3d_UParameter(self, *args)

    def VParameter(self, *args) -> "Standard_Real":
        r"""
        Returns the v parameter of the intersection point on the surface.

        Returns
        -------
        float

        """
        return _BRepClass3d.BRepClass3d_Intersector3d_VParameter(self, *args)

    def WParameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter of the intersection point on the line.

        Returns
        -------
        float

        """
        return _BRepClass3d.BRepClass3d_Intersector3d_WParameter(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass3d.delete_BRepClass3d_Intersector3d

# Register BRepClass3d_Intersector3d in _BRepClass3d:
_BRepClass3d.BRepClass3d_Intersector3d_swigregister(BRepClass3d_Intersector3d)

class BRepClass3d_SClassifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        Constructor to classify the point p with the tolerance tol on the solid s.

        Parameters
        ----------
        S: BRepClass3d_SolidExplorer
        P: gp_Pnt
        Tol: float

        Returns
        -------
        None

        """
        _BRepClass3d.BRepClass3d_SClassifier_swiginit(self, _BRepClass3d.new_BRepClass3d_SClassifier(*args))

    def Face(self, *args) -> "TopoDS_Face":
        r"""
        Returns the face used to determine the classification. when the state is on, this is the face containing the point. //! when rejected() returns true, face() has no signification.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepClass3d.BRepClass3d_SClassifier_Face(self, *args)

    def IsOnAFace(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when the point is a point of a face.

        Returns
        -------
        bool

        """
        return _BRepClass3d.BRepClass3d_SClassifier_IsOnAFace(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Classify the point p with the tolerance tol on the solid s.

        Parameters
        ----------
        S: BRepClass3d_SolidExplorer
        P: gp_Pnt
        Tol: float

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SClassifier_Perform(self, *args)

    def PerformInfinitePoint(self, *args) -> "void":
        r"""
        Classify an infinite point with the tolerance tol on the solid s.

        Parameters
        ----------
        S: BRepClass3d_SolidExplorer
        Tol: float

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SClassifier_PerformInfinitePoint(self, *args)

    def Rejected(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the classification has been computed by rejection. the state is then out.

        Returns
        -------
        bool

        """
        return _BRepClass3d.BRepClass3d_SClassifier_Rejected(self, *args)

    def State(self, *args) -> "TopAbs_State":
        r"""
        Returns the result of the classification.

        Returns
        -------
        TopAbs_State

        """
        return _BRepClass3d.BRepClass3d_SClassifier_State(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass3d.delete_BRepClass3d_SClassifier

# Register BRepClass3d_SClassifier in _BRepClass3d:
_BRepClass3d.BRepClass3d_SClassifier_swigregister(BRepClass3d_SClassifier)

class BRepClass3d_SolidExplorer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        _BRepClass3d.BRepClass3d_SolidExplorer_swiginit(self, _BRepClass3d.new_BRepClass3d_SolidExplorer(*args))

    def Box(self, *args) -> "Bnd_Box const &":
        r"""
        No available documentation.

        Returns
        -------
        Bnd_Box

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_Box(self, *args)

    def CurrentFace(self, *args) -> "TopoDS_Face":
        r"""
        Returns the current face.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_CurrentFace(self, *args)

    def CurrentShell(self, *args) -> "TopoDS_Shell":
        r"""
        Returns the current shell.

        Returns
        -------
        TopoDS_Shell

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_CurrentShell(self, *args)

    def Destroy(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_Destroy(self, *args)

    def DumpSegment(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt
        L: gp_Lin
        Par: float
        S: TopAbs_State

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_DumpSegment(self, *args)

    @staticmethod
    def FindAPointInTheFace(*args) -> "Standard_Real &, Standard_Real &":
        r"""
        Compute a point p in the face f. param is a real in ]0,1[ and is used to initialise the algorithm. for different values , different points are returned.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt

        Returns
        -------
        Param: float
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt

        Returns
        -------
        u: float
        v: float
        Param: float
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt
        theVecD1U: gp_Vec
        theVecD1V: gp_Vec

        Returns
        -------
        u: float
        v: float
        Param: float
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt

        Returns
        -------
        u: float
        v: float
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        u: float
        v: float

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_FindAPointInTheFace(*args)

    def GetFaceSegmentIndex(self, *args) -> "Standard_Integer":
        r"""
        Returns the index of face for which last segment is calculated.

        Returns
        -------
        int

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_GetFaceSegmentIndex(self, *args)

    def GetMapEV(self, *args) -> "TopTools_IndexedMapOfShape const &":
        r"""
        Return edge/vertices map for current shape.

        Returns
        -------
        TopTools_IndexedMapOfShape

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_GetMapEV(self, *args)

    def GetShape(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_GetShape(self, *args)

    def GetTree(self, *args) -> "BRepClass3d_BndBoxTree const &":
        r"""
        Return ub-tree instance which is used for edge / vertex checks.

        Returns
        -------
        BRepClass3d_BndBoxTree

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_GetTree(self, *args)

    def InitFace(self, *args) -> "void":
        r"""
        Starts an exploration of the faces of the current shell.

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_InitFace(self, *args)

    def InitShape(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_InitShape(self, *args)

    def InitShell(self, *args) -> "void":
        r"""
        Starts an exploration of the shells.

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_InitShell(self, *args)

    def Intersector(self, *args) -> "IntCurvesFace_Intersector &":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        IntCurvesFace_Intersector

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_Intersector(self, *args)

    def MoreFace(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if current face in current shell.

        Returns
        -------
        bool

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_MoreFace(self, *args)

    def MoreShell(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there is a current shell.

        Returns
        -------
        bool

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_MoreShell(self, *args)

    def NextFace(self, *args) -> "void":
        r"""
        Sets the explorer to the next face of the current shell.

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_NextFace(self, *args)

    def NextShell(self, *args) -> "void":
        r"""
        Sets the explorer to the next shell.

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_NextShell(self, *args)

    def OtherSegment(self, *args) -> "Standard_Integer":
        r"""
        Returns in <l>, <par> a segment having at least one intersection with the shape boundary to compute intersections. //! the first call to this method returns a line which point to a point of the first face of the shape. the second call provide a line to the second face and so on.

        Parameters
        ----------
        P: gp_Pnt
        L: gp_Lin

        Returns
        -------
        Par: float

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_OtherSegment(self, *args)

    def PointInTheFace(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt

        Returns
        -------
        u: float
        v: float
        Param: float
        Index: int
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt
        surf: BRepAdaptor_HSurface
        u1: float
        v1: float
        u2: float
        v2: float

        Returns
        -------
        u: float
        v: float
        Param: float
        Index: int
        <index> gives point index to search from and returns point index of succeseful search.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pnt
        surf: BRepAdaptor_HSurface
        u1: float
        v1: float
        u2: float
        v2: float
        theVecD1U: gp_Vec
        theVecD1V: gp_Vec

        Returns
        -------
        u: float
        v: float
        Param: float
        Index: int

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_PointInTheFace(self, *args)

    def Reject(self, *args) -> "Standard_Boolean":
        r"""
        Should return true if p outside of bounding vol. of the shape.

        Parameters
        ----------
        P: gp_Pnt

        Returns
        -------
        bool

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_Reject(self, *args)

    def RejectFace(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the face is rejected.

        Parameters
        ----------
        L: gp_Lin

        Returns
        -------
        bool

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_RejectFace(self, *args)

    def RejectShell(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the shell is rejected.

        Parameters
        ----------
        L: gp_Lin

        Returns
        -------
        bool

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_RejectShell(self, *args)

    def Segment(self, *args) -> "Standard_Integer":
        r"""
        Returns in <l>, <par> a segment having at least one intersection with the shape boundary to compute intersections.

        Parameters
        ----------
        P: gp_Pnt
        L: gp_Lin

        Returns
        -------
        Par: float

        """
        return _BRepClass3d.BRepClass3d_SolidExplorer_Segment(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass3d.delete_BRepClass3d_SolidExplorer

# Register BRepClass3d_SolidExplorer in _BRepClass3d:
_BRepClass3d.BRepClass3d_SolidExplorer_swigregister(BRepClass3d_SolidExplorer)

def BRepClass3d_SolidExplorer_FindAPointInTheFace(*args) -> "Standard_Real &, Standard_Real &":
    r"""
    Compute a point p in the face f. param is a real in ]0,1[ and is used to initialise the algorithm. for different values , different points are returned.

    Parameters
    ----------
    F: TopoDS_Face
    P: gp_Pnt

    Returns
    -------
    Param: float
    No available documentation.

    Parameters
    ----------
    F: TopoDS_Face
    P: gp_Pnt

    Returns
    -------
    u: float
    v: float
    Param: float
    No available documentation.

    Parameters
    ----------
    F: TopoDS_Face
    P: gp_Pnt
    theVecD1U: gp_Vec
    theVecD1V: gp_Vec

    Returns
    -------
    u: float
    v: float
    Param: float
    No available documentation.

    Parameters
    ----------
    F: TopoDS_Face
    P: gp_Pnt

    Returns
    -------
    u: float
    v: float
    No available documentation.

    Parameters
    ----------
    F: TopoDS_Face
    P: gp_Pnt

    Returns
    -------
    bool
    No available documentation.

    Parameters
    ----------
    F: TopoDS_Face

    Returns
    -------
    u: float
    v: float

    """
    return _BRepClass3d.BRepClass3d_SolidExplorer_FindAPointInTheFace(*args)

class BRepClass3d_SolidPassiveClassifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an undefined classifier.

        Returns
        -------
        None

        """
        _BRepClass3d.BRepClass3d_SolidPassiveClassifier_swiginit(self, _BRepClass3d.new_BRepClass3d_SolidPassiveClassifier(*args))

    def Compare(self, *args) -> "void":
        r"""
        Updates the classification process with the face <f> from the boundary.

        Parameters
        ----------
        F: TopoDS_Face
        Or: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidPassiveClassifier_Compare(self, *args)

    def HasIntersection(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if an intersection is computed.

        Returns
        -------
        bool

        """
        return _BRepClass3d.BRepClass3d_SolidPassiveClassifier_HasIntersection(self, *args)

    def Intersector(self, *args) -> "BRepClass3d_Intersector3d &":
        r"""
        Returns the intersecting algorithm.

        Returns
        -------
        BRepClass3d_Intersector3d

        """
        return _BRepClass3d.BRepClass3d_SolidPassiveClassifier_Intersector(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the current value of the parameter.

        Returns
        -------
        float

        """
        return _BRepClass3d.BRepClass3d_SolidPassiveClassifier_Parameter(self, *args)

    def Reset(self, *args) -> "void":
        r"""
        Starts a classification process. the point to classify is the origin of the line <l>. <p> is the original length of the segment on <l> used to compute intersections. <tol> is the tolerance attached to the intersections.

        Parameters
        ----------
        L: gp_Lin
        P: float
        Tol: float

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidPassiveClassifier_Reset(self, *args)

    def State(self, *args) -> "TopAbs_State":
        r"""
        Returns the current state of the point.

        Returns
        -------
        TopAbs_State

        """
        return _BRepClass3d.BRepClass3d_SolidPassiveClassifier_State(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass3d.delete_BRepClass3d_SolidPassiveClassifier

# Register BRepClass3d_SolidPassiveClassifier in _BRepClass3d:
_BRepClass3d.BRepClass3d_SolidPassiveClassifier_swigregister(BRepClass3d_SolidPassiveClassifier)

class BRepClass3d_SolidClassifier(BRepClass3d_SClassifier):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        Constructor from a shape.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None
        Constructor to classify the point p with the tolerance tol on the solid s.

        Parameters
        ----------
        S: TopoDS_Shape
        P: gp_Pnt
        Tol: float

        Returns
        -------
        None

        """
        _BRepClass3d.BRepClass3d_SolidClassifier_swiginit(self, _BRepClass3d.new_BRepClass3d_SolidClassifier(*args))

    def Destroy(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidClassifier_Destroy(self, *args)

    def Load(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidClassifier_Load(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Classify the point p with the tolerance tol on the solid s.

        Parameters
        ----------
        P: gp_Pnt
        Tol: float

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidClassifier_Perform(self, *args)

    def PerformInfinitePoint(self, *args) -> "void":
        r"""
        Classify an infinite point with the tolerance tol on the solid s. useful for compute the orientation of a solid.

        Parameters
        ----------
        Tol: float

        Returns
        -------
        None

        """
        return _BRepClass3d.BRepClass3d_SolidClassifier_PerformInfinitePoint(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepClass3d.delete_BRepClass3d_SolidClassifier

# Register BRepClass3d_SolidClassifier in _BRepClass3d:
_BRepClass3d.BRepClass3d_SolidClassifier_swigregister(BRepClass3d_SolidClassifier)


@classnotwrapped
class BRepClass3d_BndBoxTreeSelectorLine:
	pass

@classnotwrapped
class BRepClass3d_BndBoxTreeSelectorPoint:
	pass






